@@ -58,20 +58,30 @@ StateChoropleth = R6Class("StateChoropleth",
 #' will use a continuous scale. A value in [2, 9] will use that many colors. 
 #' @param zoom An optional vector of states to zoom in on. Elements of this vector must exactly 
 #' match the names of states as they appear in the "region" column of ?state.regions.
-#' 
+#' @param reference_map If true, render the choropleth over a reference map from Google Maps.
 #' @examples
 #' \dontrun{
 #' # default parameters
 #' data(df_pop_state)
-#' state_choropleth(df_pop_state, title="US 2012 State Population Estimates", legend="Population")
+#' state_choropleth(df_pop_state, 
+#'                  title  = "US 2012 State Population Estimates", 
+#'                  legend = "Population")
+#'
+#' # choropleth over reference map of continental usa
+#' data(continental_us_states)
+#' state_choropleth(df_pop_state, 
+#'                  title         = "US 2012 State Population Estimates",
+#'                  legend        = "Population",
+#'                  zoom          = continental_us_states, 
+#'                  reference_map = TRUE)
 #'
 #' # continuous scale and zoom
 #' data(df_pop_state)
 #' state_choropleth(df_pop_state, 
-#'                  title="US 2012 State Population Estimates", 
-#'                  legend="Population", 
-#'                  num_colors=1,
-#'                  zoom=c("california", "oregon", "washington"))
+#'                  title      = "US 2012 State Population Estimates", 
+#'                  legend     = "Population", 
+#'                  num_colors = 1,
+#'                  zoom       = c("california", "oregon", "washington"))
 #' 
 #' # demonstrate user creating their own discretization of the input
 #' # demonstrate how choroplethr handles character and factor values
@@ -87,7 +97,8 @@ StateChoropleth = R6Class("StateChoropleth",
 #'   }
 #' }
 #' df_pop_state$value = df_pop_state$str
-#' state_choropleth(df_pop_state, title="Which states have less than 1M people?")
+#' state_choropleth(df_pop_state, title = "Which states have less than 1M people?")
+#'
 #' }
 #' @export
 #' @importFrom Hmisc cut2
@@ -96,12 +107,20 @@ StateChoropleth = R6Class("StateChoropleth",
 #' @importFrom ggplot2 scale_fill_continuous scale_colour_brewer
 #' @importFrom scales comma
 #' @importFrom grid unit
-state_choropleth = function(df, title="", legend="", num_colors=7, zoom=NULL)
+state_choropleth = function(df, title="", legend="", num_colors=7, zoom=NULL, reference_map = FALSE)
 {
   c = StateChoropleth$new(df)
   c$title  = title
   c$legend = legend
   c$set_num_colors(num_colors)
   c$set_zoom(zoom)
-  c$render()
+  if (reference_map) {
+    if (is.null(zoom))
+    {
+      stop("Reference maps do not currently work with maps that have insets, such as maps of the 50 US States.")
+    }
+    c$render_with_reference_map()
+  } else {
+    c$render()
+  }
 }
